@@ -17,13 +17,19 @@
 Define Channel helping methods
 """
 from async_channel.util import channel_creator
+from async_channel.util import logging_util
 
 from async_channel.util.channel_creator import (
     create_all_subclasses_channel,
     create_channel_instance,
 )
 
+from async_channel.util.logging_util import (
+    get_logger,
+)
+
 __all__ = [
     "create_all_subclasses_channel",
     "create_channel_instance",
+    "get_logger",
 ]
